@@ -7,9 +7,10 @@ Test assigning iterator functionality.
 """
 
 from seqan.test import fasta_file
-import seqan
+import seqan.traverse
 import logging
 import sys
+import time
 from copy import copy
 
 # The different indexes we want to test
@@ -123,6 +124,78 @@ def _build_index():
         yield Index(sequences)
 
 
+class DescenderTest(object):
+    def __init__(self):
+        self.n = 0
+
+    def descend(self, it):
+        """Descend the index."""
+        self.n += 1
+        if it.goDown():
+            while True:
+                self.descend(copy(it))
+                if not it.goRight():
+                    break
+
+    def descendhistory(self, it):
+        """Descend the index."""
+        self.n += 1
+        if it.goDown():
+            while True:
+                self.descendhistory(it)
+                if not it.goRight():
+                    break
+            it.goUp()
+
+
+def test_compare_history_and_non_history():
+    for Index in Indexes:
+        for seqs in sequence_sets:
+            index = Index(make_string_set(seqs))
+            descendertopdown = DescenderTest()
+            descendertopdown.descend(index.topdown())
+            descendertopdownhistory = DescenderTest()
+            descendertopdownhistory.descendhistory(index.topdownhistory())
+            assert descendertopdown.n == descendertopdownhistory.n
+
+
+def _test_iterator_speed():
+    numdescents = 10
+    def visitnode(parent, it):
+        pass
+    def timeit(method, history):
+        start = time.time()
+        for i in xrange(numdescents):
+            descender = DescenderTest()
+            method(descender, history and index.topdownhistory() or index.topdown())
+            assert descender.n == 9766, descender.n
+        end = time.time()
+        return (end-start)/numdescents
+    def timegonext():
+        start = time.time()
+        for i in xrange(numdescents):
+            it = index.topdownhistory()
+            it.goBegin()
+            n = 0
+            while not it.atEnd:
+                n += 1
+                it.goNext()
+            assert n == 9766, n
+        end = time.time()
+        return (end-start)/numdescents
+    for index in _build_index():
+        for history in (True, False):
+            t = timeit(DescenderTest.descend, history)
+            logging.info('%.4fs with history=%-8s for %s', t, history, index)
+            if history:
+                t = timeit(DescenderTest.descendhistory, True)
+                logging.info('%.4fs with descendhistory() for %s', t, index)
+                t = timegonext()
+                logging.info('%.4fs with goNext()         for %s', t, index)
+
+
+
+
 def _test_iterator(index, Iterator):
     i = Iterator(index)
     assert i.numOccurrences >= i.numChildren
@@ -187,6 +260,17 @@ def test_get_occurrences():
             _test_get_occurrences(index, Iterator)
 
 
+def _test_iterable():
+    """Test if iterator is iterable"""
+    logging.info(sys._getframe().f_code.co_name)
+    seqs = _make_test_string_set()
+    for Index in Indexes:
+        index = Index(seqs)
+        for i in index:
+            logging.info(i.representative)
+        1/0
+
+
 def test_by_value_init():
     """Test by-value initialisation"""
     logging.info(sys._getframe().f_code.co_name)
@@ -201,28 +285,6 @@ def test_by_value_init():
     logging.info(j.representative)
 
 
-class TestParallelDescender(seqan.ParallelDescender):
-    def __init__(self, secondaryidx):
-        self.secondaryidx = secondaryidx
-
-    def _visit_node(self, primaryit, secondaryit, stillsynced):
-        logging.debug("%-10s : %-10s : %s",
-            primaryit.representative, secondaryit.representative,
-            stillsynced and "    synced" or "not synced")
-        # Descend secondary index from top as far as we can whilst
-        # matching primary representative
-        it = self.secondaryidx.topdown()
-        while it.repLength < primaryit.repLength and \
-                it.goDown(primaryit.representative[it.repLength]):
-            if it.representative[:it.repLength] != primaryit.representative[:it.repLength]:
-                break
-        # Make sure still synced matches reality
-        assert (it.representative[:primaryit.repLength] == primaryit.representative) \
-            == stillsynced
-        if (secondaryit.representative[:primaryit.repLength] == primaryit.representative) \
-            != stillsynced: 1/0
-
-
 
 sequence_sets = (
     ('GGCAAT', 'GGCAAA'),
@@ -237,6 +299,22 @@ sequence_sets = (
 
 
 def test_parallel_descender():
+    def visitvertex(primaryit, secondaryit, stillsynced):
+        logging.debug("%-10s : %-10s : %s",
+            primaryit.representative, secondaryit.representative,
+            stillsynced and "    synced" or "not synced")
+        # Descend secondary index from top as far as we can whilst
+        # matching primary representative
+        it = secondaryindex.topdown()
+        while it.repLength < primaryit.repLength and \
+                it.goDown(primaryit.representative[it.repLength]):
+            if it.representative[:it.repLength] != primaryit.representative[:it.repLength]:
+                break
+        # Make sure still synced matches reality
+        assert (it.representative[:primaryit.repLength] == primaryit.representative) \
+            == stillsynced
+        if (secondaryit.representative[:primaryit.repLength] == primaryit.representative) \
+            != stillsynced: 1/0
     for primaryseqs in sequence_sets:
         for secondaryseqs in sequence_sets:
             for seq in primaryseqs:
@@ -245,10 +323,14 @@ def test_parallel_descender():
                 logging.info('Secondary: %s', seq)
             primaryindex = seqan.IndexStringDNA5SetESA(make_string_set(primaryseqs))
             secondaryindex = seqan.IndexStringDNA5SetESA(make_string_set(secondaryseqs))
-            TestParallelDescender(secondaryindex).descend(
-                primaryindex.topdown(), secondaryindex.topdown())
+            seqan.traverse.topdownparallel(
+                primaryindex.topdown(),
+                secondaryindex.topdown(),
+                visitvertex)
             #if primaryseqs != secondaryseqs: 1/0  # Just for debugging
 
 
 if '__main__' == __name__:
-    test_get_occurrences()
+    logging.basicConfig(level=logging.INFO)
+    _test_iterator_speed()
+    #test_get_occurrences()
